@@ -1,10 +1,8 @@
 #该脚本用于合并资源
 import argparse
-from ast import Not
-import json
-import merge_file
-import merge_xml
-import merge_public
+from  merge_res.merge_file import merge_file
+from  merge_res.merge_xml import merge_xml
+from  merge_res.merge_public import merge_public
 
    
 
